create or replace package body typo3_dbLock AS

	function get_lock(i_lockName     in varchar2, 
                      i_readOnly     in boolean, 
                      i_timeout      in number default 10)
        return integer 
    is  
        m_lockHandle        varchar2(100);
        m_lockMode          integer;
        m_lockResult        integer := 0;
        m_retVal            integer := 0;
    begin
        
        --set lockmode
        if i_readOnly then
            m_lockMode := 4;
        else
            m_lockMode := 6;
        end if;
        
        --get lock handle
        dbms_lock.allocate_unique(i_lockName, m_lockHandle);
        
        --try to get the lock
        m_lockResult := dbms_lock.request(lockhandle        => m_lockHandle,
		                                  lockmode          => m_lockMode,
		                                  timeout           => i_timeout,
		                                  release_on_commit => false);
        
        --reset return value "mysql like"
        if m_lockResult = 0 then
            --locked successful
            m_retVal := 1;
        elsif m_lockResult = 2 then
            --timeout
            m_retVal := 0;
        else
            --some other error
            m_retVal := null;
        end if;
        
        return m_retVal;
        
    end get_lock;
        
	function release_lock(i_lockName in varchar2)
        return integer
    is
        m_lockHandle        varchar2(100);
        m_lockResult        integer := 0;
        m_retVal            integer := 1;
    begin
    
        --get lock handle
        dbms_lock.allocate_unique(i_lockName, m_lockHandle);
        
        --release lock
        m_lockResult := dbms_lock.release(m_lockHandle);
    
        --reset return value "mysql like"
        if m_lockResult = 0 then
            --locked successful
            m_retVal := 1;
        elsif m_lockResult = 4 then
            --timeout
            m_retVal := 0;
        else
            --some other error
            m_retVal := null;
        end if;
        
        return m_retVal;
        
    end release_lock;
    
END typo3_dbLock;
/
